citrine.informatics.design_spaces.data_source_design_space module

class citrine.informatics.design_spaces.data_source_design_space.DataSourceDesignSpace(name: str, *, description: str, data_source: DataSource)

Bases: Resource[DataSourceDesignSpace], DesignSubspace

An enumeration of candidates stored in a data source.

Parameters:
  • name (str) – the name of the design space

  • description (str) – the description of the design space

  • data_source (DataSource) – the source of data for this design space

access_control_dict() dict

Return an access control entity representation of this resource. Internal use only.

classmethod build(data: dict) Self

Build an instance of this object from given data.

dump() dict

Dump this instance.

classmethod get_type(data) type[DesignSubspace]

Return the subtype.

data_source: DataSource = None
description: str = None
name: str = None
typ = 'DataSourceDesignSpace'