citrine.informatics.experiment_values module
- class citrine.informatics.experiment_values.CategoricalExperimentValue(value: str)
Bases:
Serializable[CategoricalExperimentValue],ExperimentValue[DEPRECATED] An experiment result with a categorical value.
- classmethod build(data: dict) Self
Build an instance of this object from given data.
- dump() dict
Dump this instance.
- classmethod get_type(data) type[Serializable]
Return the subtype.
- typ = 'CategoricalValue'
- value = None
- class citrine.informatics.experiment_values.ChemicalFormulaExperimentValue(value: str)
Bases:
Serializable[ChemicalFormulaExperimentValue],ExperimentValue[DEPRECATED] Experiment value for a chemical formula.
- classmethod build(data: dict) Self
Build an instance of this object from given data.
- dump() dict
Dump this instance.
- classmethod get_type(data) type[Serializable]
Return the subtype.
- typ = 'InorganicValue'
- value = None
- class citrine.informatics.experiment_values.ExperimentValue
Bases:
PolymorphicSerializable[ExperimentValue][DEPRECATED] An container for experiment values.
Abstract type that returns the proper type given a serialized dict.
- classmethod build(data: dict) ExperimentValue
Build the underlying type.
Deprecated since version 4.1.0: This will be removed in 5.0.0. Replaced by creating materials from candidates.
- classmethod get_type(data) type[Serializable]
Return the subtype.
- class citrine.informatics.experiment_values.IntegerExperimentValue(value: int)
Bases:
Serializable[IntegerExperimentValue],ExperimentValue[DEPRECATED] An integer value experiment result.
- classmethod build(data: dict) Self
Build an instance of this object from given data.
- dump() dict
Dump this instance.
- classmethod get_type(data) type[Serializable]
Return the subtype.
- typ = 'IntegerValue'
- value = None
- class citrine.informatics.experiment_values.MixtureExperimentValue(value: dict[str, float])
Bases:
Serializable[MixtureExperimentValue],ExperimentValue[DEPRECATED] An experiment result mapping ingredients and labels to real values.
- classmethod build(data: dict) Self
Build an instance of this object from given data.
- dump() dict
Dump this instance.
- classmethod get_type(data) type[Serializable]
Return the subtype.
- typ = 'MixtureValue'
- value = None
- class citrine.informatics.experiment_values.MolecularStructureExperimentValue(value: str)
Bases:
Serializable[MolecularStructureExperimentValue],ExperimentValue[DEPRECATED] Experiment value for a molecular structure.
- classmethod build(data: dict) Self
Build an instance of this object from given data.
- dump() dict
Dump this instance.
- classmethod get_type(data) type[Serializable]
Return the subtype.
- typ = 'OrganicValue'
- value = None
- class citrine.informatics.experiment_values.RealExperimentValue(value: float)
Bases:
Serializable[RealExperimentValue],ExperimentValue[DEPRECATED] A floating point experiment result.
- classmethod build(data: dict) Self
Build an instance of this object from given data.
- dump() dict
Dump this instance.
- classmethod get_type(data) type[Serializable]
Return the subtype.
- typ = 'RealValue'
- value = None