citrine.informatics.design_spaces.design_space module
- class citrine.informatics.design_spaces.design_space.DesignSpace
Bases:
objectParent type of the individual design space on the Citrine Platform.
The Predictor class unifies TopLevelDesignSpace types and the DesignSubspace types, but does not provide any functionality on its own.