citrine.informatics.design_spaces.formulation_design_space module
- class citrine.informatics.design_spaces.formulation_design_space.FormulationDesignSpace(name: str, *, description: str, formulation_descriptor: FormulationDescriptor, ingredients: set[str], constraints: set[Constraint], labels: Mapping[str, set[str]] | None = None, resolution: float = 0.0001)
Bases:
Resource[FormulationDesignSpace],DesignSubspaceDesign space composed of mixtures of ingredients.
- Parameters:
name (str) – the name of the design space
description (str) – the description of the design space
formulation_descriptor (FormulationDescriptor) – descriptor used to store formulations sampled from the design space
ingredients (set[str]) – set of ingredient names that can be used in a formulation
constraints (set[IngredientConstraint]) – set of constraints that restricts formulations sampled from the space. This must include an
IngredientCountConstraintwith maximum count of 32 or fewer.labels (Mapping[str, set[str]] | None) – map from a label to each ingredient that should given that label when it’s included in a formulation, e.g.,
{'solvent': {'water', 'alcohol'}}resolution (float, optional) – Minimum increment used to specify ingredient quantities. Default is 0.0001.
- access_control_dict() dict
Return an access control entity representation of this resource. Internal use only.
- classmethod build(data: dict) Self
Build an instance of this object from given data.
- dump() dict
Dump this instance.
- classmethod get_type(data) type[DesignSubspace]
Return the subtype.
- constraints: set[Constraint] = None
- description: str = None
- formulation_descriptor: FormulationDescriptor = None
- ingredients: set[str] = None
- labels: Mapping[str, set[str]] | None = None
- name: str = None
- resolution: float = None
- typ = 'FormulationDesignSpace'