citrine.informatics.design_spaces.subspace module
- class citrine.informatics.design_spaces.subspace.DesignSubspace
Bases:
PolymorphicSerializable[DesignSubspace],DesignSpaceAn individual subspace within a Design Space.
A DesignSubspace cannot be registered to the Citrine Platform by itself and must be included as a component within a ProductDesignSpace or HierarchicalDesignSpace to be used.
- classmethod build(data: dict) SelfType
Build the underlying type.
- classmethod get_type(data) type[DesignSubspace]
Return the subtype.
- description = None
- name = None