citrine.informatics.predictors.simple_mixture_predictor module
- class citrine.informatics.predictors.simple_mixture_predictor.SimpleMixturePredictor(name: str, *, description: str)
Bases:
Resource[SimpleMixturePredictor],PredictorNodeA predictor interface that flattens a formulation into a simple mixture.
- Parameters:
name (str) – name of the configuration
description (str) – description of the predictor
- access_control_dict() dict
Return an access control entity representation of this resource. Internal use only.
- classmethod build(data: dict) Self
Build an instance of this object from given data.
- dump() dict
Dump this instance.
- classmethod get_type(data) type[PredictorNode]
Return the subtype.
- description: str = None
- property input_descriptor: FormulationDescriptor
The input formulation descriptor with key ‘Formulation’.
- name: str = None
- property output_descriptor: FormulationDescriptor
The output formulation descriptor with key ‘Flat Formulation’.
- typ = 'SimpleMixture'